<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.UI.UIAutomation.Core

Windows Runtime (WinRT) APIs for for the `Windows.UI.UIAutomation.Core` namespace.

This package provides the `winrt.windows.ui.uiautomation.core` module.
